==> orionis-0.363.0.tar.gz: orionis-0.363.0/orionis/foundation/config/logging/entities/hourly.py <==
from dataclasses import asdict, dataclass, field, fields
from orionis.foundation.exceptions import OrionisIntegrityException
from orionis.foundation.config.logging.enums import Level

@dataclass(unsafe_hash=True, kw_only=True)
class Hourly:
    """
    Represents the configuration for hourly log file management.

    Attributes:
        path (str): The file path where the log is stored.
        level (int | str | Level): The logging level (e.g., 'info', 'error', 'debug').
        retention_hours (int): The number of hours to retain log files before deletion.
    """

    path: str = field(
        default='storage/log/application.log',
        metadata={
            "description": "The file path where the log is stored.",
            "default": "storage/log/application.log",
        },
    )

    level: int | str | Level = field(
        default=Level.INFO,
        metadata={
            "description": "The logging level (e.g., 'info', 'error', 'debug').",
            "default": Level.INFO,
        },
    )

    retention_hours: int = field(
        default=24,
        metadata={
            "description": "The number of hours to retain log files before deletion.",
            "default": 24,
        },
    )

    def __post_init__(self):
        """
        Validates the attributes after dataclass initialization.

        Raises:
            OrionisIntegrityException: If any attribute is invalid.
                - 'path' must be a non-empty string.
                - 'level' must be an int, str, or Level enum, and a valid value.
                - 'retention_hours' must be an integer between 1 and 168.
        """
        # Validate 'path'
        if not isinstance(self.path, str) or not self.path.strip():
            raise OrionisIntegrityException(
                f"File cache configuration error: 'path' must be a non-empty string, got {repr(self.path)}."
            )

        # Validate 'level'
        valid_level_types = (int, str, Level)
        if not isinstance(self.level, valid_level_types):
            raise OrionisIntegrityException(
                f"File cache configuration error: 'level' must be int, str, or Level enum, got {type(self.level).__name__}."
            )

        if isinstance(self.level, str):
            _value = self.level.strip().upper()
            if not _value:
                raise OrionisIntegrityException(
                    "File cache configuration error: 'level' string cannot be empty."
                )
            if _value not in Level.__members__:
                raise OrionisIntegrityException(
                    f"File cache configuration error: 'level' must be one of {list(Level.__members__.keys())}, got '{self.level}'."
                )
            self.level = Level[_value].value
        elif isinstance(self.level, int):
            valid_values = [level.value for level in Level]
            if self.level not in valid_values:
                raise OrionisIntegrityException(
                    f"File cache configuration error: 'level' must be one of {valid_values}, got '{self.level}'."
                )
        elif isinstance(self.level, Level):
            self.level = self.level.value

        # Validate 'retention_hours'
        if not isinstance(self.retention_hours, int) or self.retention_hours < 0:
            raise OrionisIntegrityException(
                f"File cache configuration error: 'retention_hours' must be a non-negative integer, got {self.retention_hours}."
            )
        if self.retention_hours < 1 or self.retention_hours > 168:
            raise OrionisIntegrityException(
                f"File cache configuration error: 'retention_hours' must be between 1 and 168, got {self.retention_hours}."
            )

    def toDict(self) -> dict:
        """
        Converts the Hourly object to a dictionary representation.

        Returns:
            dict: A dictionary containing all the dataclass fields and their values.
        """
        return asdict(self)

    def getFields(self):
        """
        Retrieves a list of field information for the current dataclass instance.

        Returns:
            list: A list of dictionaries, each containing details about a field:
                - name (str): The name of the field.
                - type (type): The type of the field.
                - default: The default value of the field, if specified; otherwise, the value from metadata or None.
                - metadata (mapping): The metadata associated with the field.
        """
        __fields = []
        for field in fields(self):
            __metadata = dict(field.metadata) or {}
            __fields.append({
                "name": field.name,
                "type": field.type.__name__ if hasattr(field.type, '__name__') else str(field.type),
                "default": field.default if (field.default is not None and '_MISSING_TYPE' not in str(field.default)) else __metadata.get('default', None),
                "metadata": __metadata
            })
        return __fields

==> orionis-0.423.0.tar.gz: orionis-0.423.0/orionis/foundation/config/logging/entities/hourly.py <==
from dataclasses import dataclass, field
from orionis.support.entities.base import BaseEntity
from orionis.foundation.config.logging.validators import IsValidLevel, IsValidPath
from orionis.foundation.exceptions import OrionisIntegrityException
from orionis.foundation.config.logging.enums import Level

@dataclass(unsafe_hash=True, kw_only=True)
class Hourly(BaseEntity):
    """
    Represents the configuration for hourly log file management.

    Attributes:
        path (str): The file path where the log is stored.
        level (int | str | Level): The logging level (e.g., 'info', 'error', 'debug').
        retention_hours (int): The number of hours to retain log files before deletion.
    """

    path: str = field(
        default = 'storage/log/hourly.log',
        metadata = {
            "description": "The file path where the log is stored.",
            "default": "storage/log/hourly.log"
        },
    )

    level: int | str | Level = field(
        default = Level.INFO.value,
        metadata = {
            "description": "The logging level (e.g., DEBUG, INFO, WARNING, ERROR, CRITICAL).",
            "default": Level.INFO.value
        },
    )

    retention_hours: int = field(
        default = 24,
        metadata = {
            "description": "The number of hours to retain log files before deletion.",
            "default": 24
        },
    )

    def __post_init__(self):
        super().__post_init__()
        """
        Validates the attributes after dataclass initialization.

        Raises:
            OrionisIntegrityException: If any attribute is invalid.
                - 'path' must be a non-empty string.
                - 'level' must be an int, str, or Level enum, and a valid value.
                - 'retention_hours' must be an integer between 1 and 168.
        """

        # Validate 'path' using the IsValidPath validator
        IsValidPath(self.path)

        # Validate 'level' using the IsValidLevel validator
        IsValidLevel(self.level)

        # Assign the level value.
        if isinstance(self.level, Level):
            self.level = self.level.value
        elif isinstance(self.level, str):
            self.level = Level[self.level.strip().upper()].value
        elif isinstance(self.level, int):
            self.level = self.level

        # Validate 'retention_hours'
        if not isinstance(self.retention_hours, int) or self.retention_hours < 0:
            raise OrionisIntegrityException(
                f"File cache configuration error: 'retention_hours' must be a non-negative integer, got {self.retention_hours}."
            )
        if self.retention_hours < 1 or self.retention_hours > 168:
            raise OrionisIntegrityException(
                f"File cache configuration error: 'retention_hours' must be between 1 and 168, got {self.retention_hours}."
            )
